==> webkit2gtk_2.43.3.orig.tar.xz: webkitgtk-2.43.3/Source/WebKit/WebProcess/Plugins/PDF/PDFPluginPasswordField.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PDFPluginPasswordField_h
#define PDFPluginPasswordField_h

#if ENABLE(LEGACY_PDFKIT_PLUGIN)

#include "PDFPluginTextAnnotation.h"

namespace WebKit {

class PDFPluginPasswordField : public PDFPluginTextAnnotation {
public:
    static Ref<PDFPluginPasswordField> create(PDFLayerController *, PDFPlugin*);
    virtual ~PDFPluginPasswordField();

    void updateGeometry() override;

private:
    PDFPluginPasswordField(PDFLayerController *pdfLayerController, PDFPlugin* plugin)
        : PDFPluginTextAnnotation(0, pdfLayerController, plugin)
    {
    }

    Ref<WebCore::Element> createAnnotationElement() override;

    bool handleEvent(WebCore::Event&) override;
};

} // namespace WebKit

#endif // ENABLE(LEGACY_PDFKIT_PLUGIN)

#endif // PDFPluginTextAnnotation_h

==> webkit2gtk_2.43.4.orig.tar.xz: webkitgtk-2.43.4/Source/WebKit/WebProcess/Plugins/PDF/PDFPluginPasswordField.h <==
/*
 * Copyright (C) 2013 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef PDFPluginPasswordField_h
#define PDFPluginPasswordField_h

#if ENABLE(LEGACY_PDFKIT_PLUGIN)

#include "PDFPluginTextAnnotation.h"

namespace WebKit {

class PDFPluginPasswordField : public PDFPluginTextAnnotation {
public:
    static Ref<PDFPluginPasswordField> create(PDFPluginBase*);
    virtual ~PDFPluginPasswordField();

    void updateGeometry() override;

private:
    PDFPluginPasswordField(PDFPluginBase* plugin)
        : PDFPluginTextAnnotation(0, plugin)
    {
    }

    Ref<WebCore::Element> createAnnotationElement() override;

    bool handleEvent(WebCore::Event&) override;
};

} // namespace WebKit

#endif // ENABLE(LEGACY_PDFKIT_PLUGIN)

#endif // PDFPluginTextAnnotation_h
